@@ -135,6 +135,40 @@ const char *obs_output_get_display_name(const char *id)
 	return (info != NULL) ? info->get_name(info->type_data) : NULL;
 }
 
+obs_module_t *obs_output_get_module(const char *id)
+{
+	obs_module_t *module = obs->first_module;
+	while (module) {
+		for (size_t i = 0; i < module->outputs.num; i++) {
+			if (strcmp(module->outputs.array[i], id) == 0) {
+				return module;
+			}
+		}
+		module = module->next;
+	}
+
+	module = obs->first_disabled_module;
+	while (module) {
+		for (size_t i = 0; i < module->outputs.num; i++) {
+			if (strcmp(module->outputs.array[i], id) == 0) {
+				return module;
+			}
+		}
+		module = module->next;
+	}
+
+	return NULL;
+}
+
+enum obs_module_load_state obs_output_load_state(const char *id)
+{
+	obs_module_t *module = obs_output_get_module(id);
+	if (!module) {
+		return OBS_MODULE_MISSING;
+	}
+	return module->load_state;
+}
+
 static const char *output_signals[] = {
 	"void start(ptr output)",
 	"void stop(ptr output, int code)",
@@ -1650,12 +1684,6 @@ static inline void send_interleaved(struct obs_output *output)
 	struct encoder_packet_time ept_local = {0};
 	bool found_ept = false;
 
-	/* do not send an interleaved packet if there's no packet of the
-	 * opposing type of a higher timestamp in the interleave buffer.
-	 * this ensures that the timestamps are monotonic */
-	if (!has_higher_opposing_ts(output, &out))
-		return;
-
 	da_erase(output->interleaved_packets, 0);
 
 	if (out.type == OBS_ENCODER_VIDEO) {
@@ -1769,7 +1797,23 @@ static size_t get_interleaved_start_idx(struct obs_output *output)
 		}
 	}
 
-	return video_idx < idx ? video_idx : idx;
+	idx = video_idx < idx ? video_idx : idx;
+
+	/* Early AAC/Opus audio packets will be for "priming" the encoder and contain silence, but they should not be
+	 * discarded. Set the idx to the first audio packet if closest PTS was <= 0. */
+	size_t first_audio_idx = idx;
+	while (output->interleaved_packets.array[first_audio_idx].type != OBS_ENCODER_AUDIO)
+		first_audio_idx++;
+
+	if (output->interleaved_packets.array[first_audio_idx].pts <= 0) {
+		for (size_t i = 0; i < MAX_OUTPUT_AUDIO_ENCODERS; i++) {
+			int audio_idx = find_first_packet_type_idx(output, OBS_ENCODER_AUDIO, i);
+			if (audio_idx >= 0 && (size_t)audio_idx < idx)
+				idx = audio_idx;
+		}
+	}
+
+	return idx;
 }
 
 static int64_t get_encoder_duration(struct obs_encoder *encoder)
@@ -1836,10 +1880,16 @@ static int prune_premature_packets(struct obs_output *output)
 	return diff > duration_usec ? max_idx + 1 : 0;
 }
 
+#define DEBUG_STARTING_PACKETS 0
+
 static void discard_to_idx(struct obs_output *output, size_t idx)
 {
 	for (size_t i = 0; i < idx; i++) {
 		struct encoder_packet *packet = &output->interleaved_packets.array[i];
+#if DEBUG_STARTING_PACKETS == 1
+		blog(LOG_DEBUG, "discarding %s packet, dts: %lld, pts: %lld",
+		     packet->type == OBS_ENCODER_VIDEO ? "video" : "audio", packet->dts, packet->pts);
+#endif
 		if (packet->type == OBS_ENCODER_VIDEO) {
 			da_pop_front(output->encoder_packet_times[packet->track_idx]);
 		}
@@ -1849,8 +1899,6 @@ static void discard_to_idx(struct obs_output *output, size_t idx)
 	da_erase_range(output->interleaved_packets, 0, idx);
 }
 
-#define DEBUG_STARTING_PACKETS 0
-
 static bool prune_interleaved_packets(struct obs_output *output)
 {
 	size_t start_idx = 0;
@@ -2153,6 +2201,24 @@ static void apply_ept_offsets(struct obs_output *output)
 	}
 }
 
+static inline size_t count_streamable_frames(struct obs_output *output)
+{
+	size_t eligible = 0;
+
+	for (size_t idx = 0; idx < output->interleaved_packets.num; idx++) {
+		struct encoder_packet *pkt = &output->interleaved_packets.array[idx];
+
+		/* Only count an interleaved packet as streamable if there are packets of the opposing type and of a
+		 * higher timestamp in the interleave buffer. This ensures that the timestamps are monotonic. */
+		if (!has_higher_opposing_ts(output, pkt))
+			break;
+
+		eligible++;
+	}
+
+	return eligible;
+}
+
 static void interleave_packets(void *data, struct encoder_packet *packet, struct encoder_packet_time *packet_time)
 {
 	struct obs_output *output = data;
@@ -2225,7 +2291,15 @@ static void interleave_packets(void *data, struct encoder_packet *packet, struct
 		} else {
 			set_higher_ts(output, &out);
 
-			send_interleaved(output);
+			size_t streamable = count_streamable_frames(output);
+			if (streamable) {
+				send_interleaved(output);
+
+				/* If we have more eligible packets queued than we normally should have,
+				 * send one additional packet until we're back below the limit. */
+				if (--streamable > output->interleaver_max_batch_size)
+					send_interleaved(output);
+			}
 		}
 	}
 
@@ -2634,6 +2708,53 @@ static void reset_raw_output(obs_output_t *output)
 	pause_reset(&output->pause);
 }
 
+static void calculate_batch_size(struct obs_output *output)
+{
+	struct obs_video_info ovi;
+	obs_get_video_info(&ovi);
+	DARRAY(uint64_t) intervals;
+	da_init(intervals);
+
+	uint64_t largest_interval = 0;
+
+	/* Step 1: Calculate the largest interval between packets of any encoder. */
+	for (size_t i = 0; i < MAX_OUTPUT_VIDEO_ENCODERS; i++) {
+		if (!output->video_encoders[i])
+			continue;
+
+		uint32_t den = ovi.fps_den * obs_encoder_get_frame_rate_divisor(output->video_encoders[i]);
+		uint64_t encoder_interval = util_mul_div64(1000000000ULL, den, ovi.fps_num);
+		da_push_back(intervals, &encoder_interval);
+
+		largest_interval = encoder_interval > largest_interval ? encoder_interval : largest_interval;
+	}
+
+	for (size_t i = 0; i < MAX_OUTPUT_AUDIO_ENCODERS; i++) {
+		if (!output->audio_encoders[i])
+			continue;
+
+		uint32_t sample_rate = obs_encoder_get_sample_rate(output->audio_encoders[i]);
+		size_t frame_size = obs_encoder_get_frame_size(output->audio_encoders[i]);
+		uint64_t encoder_interval = util_mul_div64(1000000000ULL, frame_size, sample_rate);
+		da_push_back(intervals, &encoder_interval);
+
+		largest_interval = encoder_interval > largest_interval ? encoder_interval : largest_interval;
+	}
+
+	/* Step 2: Calculate how many packets would fit into double that interval given each encoder's packet rate.
+	 * The doubling is done to provide some amount of wiggle room as the largest interval may not be evenly
+	 * divisible by all smaller ones. For example, 33.3... ms video (30 FPS) and 21.3... ms audio (48 kHz AAC). */
+	for (size_t i = 0; i < intervals.num; i++) {
+		uint64_t num = (largest_interval * 2) / intervals.array[i];
+		output->interleaver_max_batch_size += num;
+	}
+
+	blog(LOG_DEBUG, "Maximum interleaver batch size for '%s' calculated to be %zu packets",
+	     obs_output_get_name(output), output->interleaver_max_batch_size);
+
+	da_free(intervals);
+}
+
 bool obs_output_begin_data_capture(obs_output_t *output, uint32_t flags)
 {
 	UNUSED_PARAMETER(flags);
@@ -2660,6 +2781,8 @@ bool obs_output_begin_data_capture(obs_output_t *output, uint32_t flags)
 	os_atomic_set_bool(&output->data_active, true);
 	hook_data_capture(output);
 
+	calculate_batch_size(output);
+
 	if (flag_service(output))
 		obs_service_activate(output->service);
 
