@@ -312,9 +312,13 @@ static inline bool init_obs_graphics_objects(syphon_t s)
     obs_enter_graphics();
     s->sampler = gs_samplerstate_create(&info);
     s->vertbuffer = create_vertbuffer();
-    obs_leave_graphics();
 
-    s->effect = obs_get_base_effect(OBS_EFFECT_DEFAULT_RECT);
+    if (gs_get_device_type() == GS_DEVICE_OPENGL) {
+        s->effect = obs_get_base_effect(OBS_EFFECT_DEFAULT_RECT);
+    } else {
+        s->effect = obs_get_base_effect(OBS_EFFECT_DEFAULT);
+    }
+    obs_leave_graphics();
 
     return s->sampler != NULL && s->vertbuffer != NULL && s->effect != NULL;
 }
